ErrorSnapshot

Struct ErrorSnapshot 

pub struct ErrorSnapshot {
    pub reason: String,
    pub detail: Option<String>,
    pub position: Option<String>,
    pub want: Option<String>,
    pub path: Option<String>,
    pub context: Vec<SnapshotContextFrame>,
    pub root_metadata: ErrorMetadata,
    pub source_frames: Vec<SnapshotSourceFrame>,
}
Stable machine-readable snapshot view derived from StructError.

This object is intentionally separate from runtime propagation semantics. It carries exported diagnostic data, but does not implement StdError or own any runtime source object handles.

Fields

reason: Stringdetail: Option<String>position: Option<String>want: Option<String>path: Option<String>context: Vec<SnapshotContextFrame>root_metadata: ErrorMetadatasource_frames: Vec<SnapshotSourceFrame>

Implementations