Module conversion

Module conversion 

Conversion traits for the current primary paths.

Traits

ConvErr
Convert a Result<T, StructError<R1>> into Result<T, StructError<R2>>.
ConvStructError
Convert a StructError<R1> into StructError<R2>.
ErrorWith
Extension methods for attaching operation context and position to an error.
SourceErr
Convert a Result<T, E> into Result<T, StructError<R>>, attaching the original error as the source of the new structured error.
ToStructError
Convenience to wrap any DomainReason value into a StructError.