Reason-layer enums and traits.
Enums
- Conf
ErrReason - Configuration error sub-classification 配置错误子分类
- Error
Category - Categorisation of an error for protocol-level routing and policy decisions.
- Unified
Reason - Universal error reason classification with clear hierarchical structure 统一错误原因分类 - 采用清晰的分层结构
Traits
- Domain
Reason - Marker trait for domain-specific error reason types.
- Error
Code - Legacy numeric error code.
- Error
Identity Provider - Runtime identity provider for stable error codes and categories.