Module reason

Module reason 

Reason-layer enums and traits.

Enums

ConfErrReason
Configuration error sub-classification 配置错误子分类
ErrorCategory
UvsReason
Universal error reason classification with clear hierarchical structure 统一错误原因分类 - 采用清晰的分层结构

Traits

DomainReason
ErrorCode
Legacy numeric error code.
ErrorIdentityProvider
UvsFrom
Unified constructor helpers for types that can be converted from UvsReason.