Reason-layer enums and traits.
Enums
- Conf
ErrReason - Configuration error sub-classification 配置错误子分类
- Error
Category - UvsReason
- Universal error reason classification with clear hierarchical structure 统一错误原因分类 - 采用清晰的分层结构
Traits
- Domain
Reason - Error
Code - Legacy numeric error code.
- Error
Identity Provider - UvsFrom
- Unified constructor helpers for types that can be converted from
UvsReason.